pub enum TunnelTopic {
Drop,
Private(TunnelName),
Public(TunnelName),
}Expand description
Indicates how a services is allowed to be routed to
Variants
Drop
All messages should be dropped
Private(TunnelName)
Only other services can route to a private channel
Public(TunnelName)
Anything can route to a public channel